#!/bin/ksh

EXITERROR="Unable to determine ITM JVM location. Exiting with error."
#WORKDIR=$PWD
WORKDIR=`dirname $0`

usage() {
  echo ""
  echo "Usage:"
  echo "  $0 -c <candle_home> [ -i <install_mode> [ -f <response_file> ] ]"
  echo ""
  echo "  where:"
  echo "     <candle_home> is the ITM base directory"
  echo "     <install_mode> is one of:"
  echo "       GUI"
  echo "       console"
  echo "       silent"
  echo "         NOTE:"
  echo "         For 'silent' install mode, a custom response file may be"
  echo "         specified via the '-f' option."
  echo ""
}

setEnv() {
   if [ -f $1/bin/dynarch.shl ]
   then
     export CANDLEHOME=$1
     . $CANDLEHOME/bin/dynarch.shl $CANDLEHOME/registry/archdsc.tbl > /dev/null 2>&1
     os=$(print $cArch|cut -c1-2)
     [[ $os = "li" || $os = "ls" ]] && ulimit -s unlimited
     setJavaEnv $cArch > /dev/null 2>&1
     if ( ls -1 ${CANDLEHOME}/registry/cq* > /dev/null 2>&1 )
     then
       TESTARCH=cq
       setBinLibArchs $cArch $TESTARCH
     elif ( ls -1 ${CANDLEHOME}/registry/cj* > /dev/null 2>&1 )
     then
       TESTARCH=cj
       setBinLibArchs $cArch $TESTARCH
     else
       echo "Neither cj nor cq found"
     fi
     
   elif [ ! -d $1 ]
   then
     echo "$1 is not a valid directory."
     echo ${EXITERROR}
     echo ""
     exit 1
   else
     echo "Cannot find bin/dynarch.shl in $1"
     echo ${EXITERROR}
     echo ""
     exit 1
   fi
}


if [ $# -lt 2 ]
then
  echo ""
  echo "Insufficient number of parameters."
  usage
  exit 1
elif [ "$1" != "-c" ]
then
  echo ""
  echo "Invalid option \'$1\'."
  usage
  exit 1
fi

setEnv $2

shift 2


echo "JAVA_HOME set to ${JAVA_HOME}."
echo "binArch found for ${TESTARCH}: $binArch"
echo "libArch found for ${TESTARCH}: $libArch"
PATH=${JAVA_HOME}/bin:$PATH
if [ -f ${WORKDIR}/lpinstaller.bin ]
then
  ${WORKDIR}/lpinstaller.bin $@
elif [ -f ${WORKDIR}/lpinstaller.jar ]
then
# This, for some reason, does not seem to communicate CANDLEHOME to the installer...
  java -jar ${WORKDIR}/lpinstaller.jar $@
else
  echo "ITM Common Language Pack Installer not found in ${WORKDIR}. Exiting with error."
  echo ""
  exit 1
fi
